@@ -109,22 +109,22 @@
         <translation type="unfinished">Запази превода</translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="129"/>
+        <location filename="../dictwidget.cpp" line="135"/>
         <source>HTML files (*.html, *.htm)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="116"/>
+        <location filename="../dictwidget.cpp" line="124"/>
         <source>Text files (*.txt)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="123"/>
+        <location filename="../dictwidget.cpp" line="130"/>
         <source>Error</source>
         <translation type="unfinished">Грешка</translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="124"/>
+        <location filename="../dictwidget.cpp" line="131"/>
         <source>Cannot save translation as %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -572,5 +572,20 @@
         <source>&amp;Quit</source>
         <translation type="unfinished">&amp;Изход</translation>
     </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>QStarDict: scanning is %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>enabled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>disabled</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
