@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="de_DE">
+<defaultcodec></defaultcodec>
 <context>
     <name>QStarDict::CSSEdit</name>
     <message>
@@ -109,22 +110,22 @@
         <translation>Übersetzung speichern</translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="129"/>
+        <location filename="../dictwidget.cpp" line="135"/>
         <source>HTML files (*.html, *.htm)</source>
         <translation>HTML-Dateien (*.html, *.htm)</translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="116"/>
+        <location filename="../dictwidget.cpp" line="124"/>
         <source>Text files (*.txt)</source>
         <translation>Textdateien (*.txt)</translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="123"/>
+        <location filename="../dictwidget.cpp" line="130"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="124"/>
+        <location filename="../dictwidget.cpp" line="131"/>
         <source>Cannot save translation as %1</source>
         <translation>Kann Übersetzung nicht als %1 speichern</translation>
     </message>
@@ -442,7 +443,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="380"/>
         <source> sec</source>
-        <translation type="unfinished"></translation>
+        <translation>Sek.</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="424"/>
@@ -572,5 +573,20 @@
         <source>&amp;Quit</source>
         <translation>&amp;Beenden</translation>
     </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>QStarDict: scanning is %1</source>
+        <translation>QStarDict: Scannen ist %1</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>enabled</source>
+        <translation>aktiviert</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>disabled</source>
+        <translation>deaktiviert</translation>
+    </message>
 </context>
 </TS>
