@@ -5,32 +5,32 @@
     <message>
         <location filename="../cssedit.ui" line="16"/>
         <source>Preview</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Попередній перегляд</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="30"/>
         <source>Element</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Елемент</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="37"/>
         <source>Foreground</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Передній план</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="44"/>
         <source>Background</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Задній план</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="51"/>
         <source>Select element</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Вибір елемента</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="68"/>
         <source>Click to select color</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Клік для вибору кольору</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="71"/>
@@ -40,22 +40,22 @@
     <message>
         <location filename="../cssedit.ui" line="78"/>
         <source>Font</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Шрифт</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="85"/>
         <source>Size</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Розмір</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="92"/>
         <source>Select font</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Вибір шрифту</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="99"/>
         <source>Select font size</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Вибір розміру шрифту</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="102"/>
@@ -65,7 +65,7 @@
     <message>
         <location filename="../cssedit.ui" line="127"/>
         <source>Bold</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Жирний</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="130"/>
@@ -75,7 +75,7 @@
     <message>
         <location filename="../cssedit.ui" line="147"/>
         <source>Italic</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Курсив</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="150"/>
@@ -85,7 +85,7 @@
     <message>
         <location filename="../cssedit.ui" line="167"/>
         <source>Underline</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Підкреслений</translation>
     </message>
     <message>
         <location filename="../cssedit.ui" line="170"/>
@@ -109,22 +109,22 @@
         <translation type="unfinished">Зберегти переклад</translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="129"/>
+        <location filename="../dictwidget.cpp" line="135"/>
         <source>HTML files (*.html, *.htm)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="116"/>
+        <location filename="../dictwidget.cpp" line="124"/>
         <source>Text files (*.txt)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="123"/>
+        <location filename="../dictwidget.cpp" line="130"/>
         <source>Error</source>
         <translation type="unfinished">Помилка</translation>
     </message>
     <message>
-        <location filename="../dictwidget.cpp" line="124"/>
+        <location filename="../dictwidget.cpp" line="131"/>
         <source>Cannot save translation as %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -257,57 +257,57 @@
     <message>
         <location filename="../settingsdialog.cpp" line="68"/>
         <source>Enabled</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Включено</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="68"/>
         <source>Name</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Ім&apos;я</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="68"/>
         <source>Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Плагін</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="261"/>
         <source>Information about dictionary &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Інформація про словник &quot;%1&quot;</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="279"/>
         <source>&lt;b&gt;Name:&lt;/b&gt; %1&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;Ім&apos;я:&lt;/b&gt; %1&lt;br&gt;</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="263"/>
         <source>&lt;b&gt;Plugin:&lt;/b&gt; %1&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;Плагін:&lt;/b&gt; %1&lt;br&gt;</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="265"/>
         <source>unknown</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">невідомо</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="283"/>
         <source>&lt;b&gt;Description:&lt;/b&gt; %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;Опис:&lt;/b&gt; %1</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="278"/>
         <source>Information about %1 plugin</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Інформація про %1 плагін</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="280"/>
         <source>&lt;b&gt;Version:&lt;/b&gt; %1&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;Версія:&lt;/b&gt; %1&lt;br&gt;</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="281"/>
         <source>&lt;b&gt;Authors:&lt;/b&gt; %1&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;Автори:&lt;/b&gt; %1&lt;br&gt;</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="281"/>
@@ -317,17 +317,17 @@
     <message>
         <location filename="../settingsdialog.cpp" line="282"/>
         <source>&lt;b&gt;Can search similar words:&lt;/b&gt; %1&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;Шукати подібні слова:&lt;/b&gt; %1&lt;br&gt;</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="282"/>
         <source>yes</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Так</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="282"/>
         <source>no</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Ні</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="13"/>
@@ -337,27 +337,27 @@
     <message>
         <location filename="../settingsdialog.ui" line="16"/>
         <source>Show information about dictionary</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Показати інформацію про словник</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="57"/>
         <source>Global settings</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Глобальні налаштування</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="63"/>
         <source>Instant search</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Миттєвий пошук</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="87"/>
         <source>Pronounce words using this command:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Вимовляти слова, використовуючи цю команду: </translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="94"/>
         <source>Enter cmd for the speaching program.&lt;br&gt;If cmd contains &quot;%s&quot; it will be replaced to word, else word will be writen to stdin of speech process.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Введіть команду для розмовної програми. &lt;br&gt;Якщо команда містить &quot;%s&quot; це буде замінено словом, інaкше слово буде записано на stdin.</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="123"/>
@@ -367,7 +367,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="147"/>
         <source>Move up</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Перейти вверх</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="150"/>
@@ -377,7 +377,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="160"/>
         <source>Move down</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Перейти вниз</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="163"/>
@@ -387,32 +387,32 @@
     <message>
         <location filename="../settingsdialog.ui" line="173"/>
         <source>Show info</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Показати інформацію</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="207"/>
         <source>Plugins</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Плагіни</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="234"/>
         <source>Show information about plugin</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Показати інформацію про плагін</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="237"/>
         <source>Info</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Інфо</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="247"/>
         <source>Configure plugin</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Налаштувати плагін</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="250"/>
         <source>Configure</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Конфігурація</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="279"/>
@@ -427,7 +427,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="344"/>
         <source>Pronounce the word</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Вимовити слово</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="370"/>
@@ -507,47 +507,47 @@
     <message>
         <location filename="../settingsdialog.cpp" line="264"/>
         <source>&lt;b&gt;Author:&lt;/b&gt; %1&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;Автор:&lt;/b&gt; %1&lt;br&gt;</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="265"/>
         <source>&lt;b&gt;Words count:&lt;/b&gt; %1&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;b&gt;Кількість слів:&lt;/b&gt; %1&lt;br&gt;</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="113"/>
         <source>All translation</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Всі переклади</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="114"/>
         <source>Dictionary name</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Ім&apos;я словника</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="115"/>
         <source>Title</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Заголовок</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="116"/>
         <source>Explanation</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Проголошення</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="117"/>
         <source>Abbreviation</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Абревіатури</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="118"/>
         <source>Example</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Приклад</translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="119"/>
         <source>Transcription</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Транскрипція</translation>
     </message>
 </context>
 <context>
@@ -572,5 +572,20 @@
         <source>&amp;Quit</source>
         <translation type="unfinished">&amp;Вихiд</translation>
     </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>QStarDict: scanning is %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>enabled</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="84"/>
+        <source>disabled</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
